@@ -270,10 +270,11 @@ mod test {
 		let recipient = BlsFr::rand(rng);
 		let fee = BlsFr::rand(rng);
 		let refund = BlsFr::rand(rng);
+		let commitment = BlsFr::rand(rng);
 		let (leaf_private, leaf_public, leaf, nullifier_hash) =
 			setup_leaf_x5(chain_id, &params5, rng);
 
-		let arbitrary_input = setup_arbitrary_data(recipient, relayer, fee, refund);
+		let arbitrary_input = setup_arbitrary_data(recipient, relayer, fee, refund, commitment);
 		let params3 = setup_params_x5_3(curve);
 		let (_, path) = setup_tree_and_create_path_tree_x5(&[leaf], 0, &params3);
 		let root = BlsFr::rand(rng);
@@ -300,6 +301,7 @@ mod test {
 		public_inputs.push(arbitrary_input.recipient);
 		public_inputs.push(arbitrary_input.relayer);
 		public_inputs.push(arbitrary_input.fee);
+		public_inputs.push(arbitrary_input.commitment);
 		let (pk, vk) =
 			setup_groth16_circuit_x5::<_, Bls12_381, TEST_N, TEST_M>(rng, circuit.clone());
 		let proof = prove_groth16_circuit_x5::<_, Bls12_381, TEST_N, TEST_M>(&pk, circuit, rng);
@@ -318,10 +320,11 @@ mod test {
 		let recipient = BlsFr::rand(rng);
 		let fee = BlsFr::rand(rng);
 		let refund = BlsFr::rand(rng);
+		let commitment = BlsFr::rand(rng);
 		let (leaf_private, leaf_public, leaf, nullifier_hash) =
 			setup_leaf_x5(chain_id, &params5, rng);
 
-		let arbitrary_input = setup_arbitrary_data(recipient, relayer, fee, refund);
+		let arbitrary_input = setup_arbitrary_data(recipient, relayer, fee, refund, commitment);
 		let params3 = setup_params_x5_3(curve);
 		let (_, path) = setup_tree_and_create_path_tree_x5(&[leaf], 0, &params3);
 		let root = BlsFr::rand(rng);
@@ -349,6 +352,7 @@ mod test {
 		public_inputs.push(arbitrary_input.recipient);
 		public_inputs.push(arbitrary_input.relayer);
 		public_inputs.push(arbitrary_input.fee);
+		public_inputs.push(arbitrary_input.commitment);
 		let (pk, vk) =
 			setup_groth16_circuit_x5::<_, Bls12_381, TEST_N, TEST_M>(rng, circuit.clone());
 		let proof = prove_groth16_circuit_x5::<_, Bls12_381, TEST_N, TEST_M>(&pk, circuit, rng);
@@ -367,9 +371,10 @@ mod test {
 		let recipient = BlsFr::rand(rng);
 		let fee = BlsFr::rand(rng);
 		let refund = BlsFr::rand(rng);
+		let commitment = BlsFr::rand(rng);
 		let (leaf_private, leaf_public, _, nullifier_hash) = setup_leaf_x5(chain_id, &params5, rng);
 		let leaf = BlsFr::rand(rng);
-		let arbitrary_input = setup_arbitrary_data(recipient, relayer, fee, refund);
+		let arbitrary_input = setup_arbitrary_data(recipient, relayer, fee, refund, commitment);
 		let params3 = setup_params_x5_3(curve);
 		let (_, path) = setup_tree_and_create_path_tree_x5(&[leaf], 0, &params3);
 		let root = BlsFr::rand(rng);
@@ -397,6 +402,7 @@ mod test {
 		public_inputs.push(arbitrary_input.recipient);
 		public_inputs.push(arbitrary_input.relayer);
 		public_inputs.push(arbitrary_input.fee);
+		public_inputs.push(arbitrary_input.commitment);
 		let (pk, vk) =
 			setup_groth16_circuit_x5::<_, Bls12_381, TEST_N, TEST_M>(rng, circuit.clone());
 		let proof = prove_groth16_circuit_x5::<_, Bls12_381, TEST_N, TEST_M>(&pk, circuit, rng);
@@ -415,9 +421,10 @@ mod test {
 		let recipient = BlsFr::rand(rng);
 		let fee = BlsFr::rand(rng);
 		let refund = BlsFr::rand(rng);
+		let commitment = BlsFr::rand(rng);
 		let (leaf_private, leaf_public, leaf, _) = setup_leaf_x5(chain_id, &params5, rng);
 		let nullifier_hash = BlsFr::rand(rng);
-		let arbitrary_input = setup_arbitrary_data(recipient, relayer, fee, refund);
+		let arbitrary_input = setup_arbitrary_data(recipient, relayer, fee, refund, commitment);
 		let params3 = setup_params_x5_3(curve);
 		let (_, path) = setup_tree_and_create_path_tree_x5(&[leaf], 0, &params3);
 		let root = BlsFr::rand(rng);
@@ -445,6 +452,7 @@ mod test {
 		public_inputs.push(arbitrary_input.recipient);
 		public_inputs.push(arbitrary_input.relayer);
 		public_inputs.push(arbitrary_input.fee);
+		public_inputs.push(arbitrary_input.commitment);
 		let (pk, vk) =
 			setup_groth16_circuit_x5::<_, Bls12_381, TEST_N, TEST_M>(rng, circuit.clone());
 		let proof = prove_groth16_circuit_x5::<_, Bls12_381, TEST_N, TEST_M>(&pk, circuit, rng);
